#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MAXLEFTSHIFT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MAXLEFTSHIFT_HPP_INCLUDED

#include <boost/simd/constant/include/constants/maxleftshift.hpp>

#endif
